"""
Django settings for example project.

For more information on this file, see
https://docs.djangoproject.com/en/3.1/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.1/ref/settings/
"""

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os
BASE_DIR = os.path.dirname(os.path.dirname(__file__))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.1/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = 'of course your production secret key wil be in ENV or other place'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

TEMPLATE_DEBUG = True

ALLOWED_HOSTS = []


# Application definition

INSTALLED_APPS = (
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',

    'crispy_forms',
    'contact_form_bootstrap',
)

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'example.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [
            os.path.join(BASE_DIR, 'contact_form_bootstrap/templates'),
            os.path.join(BASE_DIR, 'example/templates'),
        ],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'example.wsgi.application'


# Database
# https://docs.djangoproject.com/en/3.1/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
    }
}

# Password validation
# https://docs.djangoproject.com/en/3.1/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]

# Internationalization
# https://docs.djangoproject.com/en/3.1/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.1/howto/static-files/

STATIC_URL = '/static/'

# for django-contact-form
ADMINS = (
    ('your admin name', 'contact@yourdomain.com'),
)

COMPANY_INFOS = {
    'NAME': "my company",
    'ADDRESS': "26 streets from here th there",
    'ZIP': "1234",
    'CITY': "Paris",
    'LAT': 48.81484460000001,
    'LNG': 2.0523723999999675,
    'PHONE': "+336 1234 5678",
    'EMAIL': 'contact@yourdomain.com',
    'FACEBOOK': "https://www.facebook.com/highfeature",
    'LINKEDIN': "http://www.linkedin.com/in/ivarsalain",
    'TWITTER': "https://twitter.com/HighFeature",
    'GOOGLEPLUS': "https://twitter.com/HighFeature",
}

CRISPY_TEMPLATE_PACK = 'bootstrap3'

USE_RECAPTCHA = False #or True
# and if you use it:
RECAPTCHA_PUBLIC_KEY = 'your reCapcha public key'
RECAPTCHA_PRIVATE_KEY = 'your reCapcha private key'



# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os
BASE_DIR = os.path.dirname(os.path.dirname(__file__))

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [
            os.path.join(BASE_DIR, 'contact_form_bootstrap/templates'),
            os.path.join(BASE_DIR, 'example/templates'),
        ],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

ADMINS = (
    ('Firstname Lastname', 'contact@mydomain.com'),
)

CONTACT_FORM_SUBJECT_TEMPLATE_NAME = 'email_subject.txt'
CONTACT_FORM_MESSAGE_TEMPLATE_NAME = 'email_message.txt'

COMPANY_INFOS = {
    'NAME': "my company",
    'ADDRESS': "26 streets from here th there",
    'ZIP': "1234",
    'CITY': "Maybe-there",
    'LAT': 48.81484460000001,
    'LNG': 2.0523723999999675,
    'PHONE': "+336 1234 5678",
    'EMAIL': 'contact@mycompany.com',
    'FACEBOOK': "http://fr-fr.facebook.com/people/Maybe-there",
    'LINKEDIN': "http://www.linkedin.com/in/Maybe-there",
    'TWITTER': "http://twitter.com/Maybe-there",
    'GOOGLEPLUS': "https://plus.google.com/Maybe-there/posts",
}

CRISPY_TEMPLATE_PACK = 'bootstrap3'

# if you use capcha overload these parameters and set USE_RECAPTCHA to True
USE_RECAPTCHA = False
RECAPTCHA_PUBLIC_KEY = 'your reCapcha public key'
RECAPTCHA_PRIVATE_KEY = 'your reCapcha private key'



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import logging

from captcha.widgets import ReCaptchaV2Checkbox
from django.conf import settings
from django.core.mail.message import EmailMessage
from django.forms import Form, CharField, EmailField, EmailInput, Textarea, TextInput
from django.template import loader
from django.utils.translation import ugettext_lazy as _

from captcha.fields import ReCaptchaField
from crispy_forms.helper import FormHelper
from crispy_forms.layout import Layout, Div, Submit
from crispy_forms.bootstrap import FormActions

logger = logging.getLogger(__name__)


class BaseEmailFormMixin(object):
    from_email = settings.DEFAULT_FROM_EMAIL
    recipient_list = [email for _, email in settings.ADMINS]

    def get_message(self):
        logger.debug('get_message')
        template = settings.CONTACT_FORM_SUBJECT_TEMPLATE_NAME or 'email_subject.txt'
        content = loader.render_to_string(template, self.get_context())
        return ''.join(content.splitlines())

    def get_subject(self):
        logger.debug('get_subject')
        template = settings.CONTACT_FORM_MESSAGE_TEMPLATE_NAME or 'email_message.txt'
        content = loader.render_to_string(template, self.get_context())
        return ''.join(content.splitlines())

    def get_context(self):
        """
        Context sent to templates for rendering include the form's cleaned
        data and also the current Request object.
        """
        logger.debug('get_context')
        if not self.is_valid():
            # import pprint
            # pprint.pprint('self %s' % self.cleaned_data)
            raise ValueError("Cannot generate Context when form is invalid.")
        return dict(request=self.request, **self.cleaned_data)

    def get_email_headers(self):
        """
        Subclasses can replace this method to define additional settings like
        a reply_to value.
        """
        logger.debug('get_email_headers')
        return None

    def get_message_dict(self):
        logger.debug('get_message_dict')
        message_dict = {
            "from_email": self.from_email,
            "to": self.recipient_list,
            "subject": self.get_subject(),
            "body": self.get_message(),
        }
        headers = self.get_email_headers()
        if headers is not None:
            message_dict['headers'] = headers
        return message_dict

    def send_email(self, request, fail_silently=False):
        logger.debug('send_email')
        assert self.recipient_list
        self.request = request
        return EmailMessage(**self.get_message_dict()).send(fail_silently=fail_silently)


class ContactForm(Form, BaseEmailFormMixin):
    """
    A very basic contact form you can use out of the box if you wish.
    """
    name = CharField(
        widget=TextInput(
            attrs={
                "placeholder": "Name",
                "class": "form-control"
            }
        ))
    email = EmailField(
        widget=EmailInput(
            attrs={
                "placeholder": "Email",
                "class": "form-control"
            }
        ))
    phone = CharField(
        widget=TextInput(
            attrs={
                "placeholder": "Phone",
                "class": "form-control"
            }
        ))
    body = CharField(
        widget=Textarea(
            attrs={
                "placeholder": "Message",
                "class": "form-control"
            }
        ))
    # captcha = ReCaptchaField(
    #     widget=ReCaptchaV2Checkbox(
    #         attrs={'theme': 'clean'}
    #     ))

    def __init__(self, *args, **kwargs):
        logger.debug('__init__')
        super(ContactForm, self).__init__(*args, **kwargs)
        # Add captcha in the constructor to allow mock it
        # because https://github.com/mbi/django-simple-captcha/issues/84
        self.fields["captcha"] = ReCaptchaField(
            widget=ReCaptchaV2Checkbox(
                attrs={'theme': 'clean'}
            )
        )
        # cryspy
        self.helper = FormHelper()
        self.helper.form_id = 'id-CcontactForm'
        self.helper.form_class = 'blueForms'
        self.helper.form_method = 'post'
        self.helper.form_class = 'form'
        if settings.USE_RECAPTCHA:
            self.helper.layout = Layout(
                Div(
                    Div('name', css_class="form-group col-lg-4"),
                    Div('email', css_class="form-group col-lg-4"),
                    Div('phone', css_class="form-group col-lg-4"),
                    Div(css_class="clearfix"),
                    Div('body', css_class="form-group col-lg-12"),
                    Div(css_class="clearfix"),
                    Div('captcha', css_class="form-group col-lg-12"),
                    FormActions(
                        Div(
                            Submit('submit', _('Submit'), css_class='btn btn-primary'),
                            css_class="form-group col-lg-12"
                        ),
                    ),
                    css_class="row",
                ),
            )
        else:
            self.helper.layout = Layout(
                Div(
                    Div('name', css_class="form-group col-lg-4"),
                    Div('email', css_class="form-group col-lg-4"),
                    Div('phone', css_class="form-group col-lg-4"),
                    Div(css_class="clearfix"),
                    Div('body', css_class="form-group col-lg-12"),
                    FormActions(
                        Div(
                            Submit('submit', _('Submit'), css_class='btn btn-primary'),
                            css_class="form-group col-lg-12"
                        ),
                    ),
                    css_class="row",
                ),
            )

    def get_email_headers(self):
        logger.debug('get_email_headers')
        return {'Reply-To': self.cleaned_data['email']}



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.urls import reverse
# from django.http import HttpResponseForbidden
from django.views.generic.base import TemplateView
from django.views.generic import FormView

from django.conf import settings
# from werkzeug.utils import redirect

from contact_form_bootstrap.forms import ContactForm


class CompletedPage(TemplateView):
    template_name = "contact_completed.html"

    def get_context_data(self, **kwargs):
        context = super(CompletedPage, self).get_context_data(**kwargs)
        context['url'] = 'contact'
        return context


class ContactFormMixin(object):
    """
    Form view that sends email when form is valid. You'll need
    to define your own form_class and template_name.
    """
    def form_valid(self, form):
        form.send_email(self.request)
        return super(ContactFormMixin, self).form_valid(form)

    def get_success_url(self):
        return reverse("completed")

# from django import forms
# class ContactForm(forms.Form):
#     """
#     Form view that sends email when form is valid. You'll need
#     to define your own form_class and template_name.
#     """
#     subject = forms.CharField(max_length=100)
#
#     def form_valid(self, form):
#         form.send_email(self.request)
#         return super(ContactForm, self).form_valid(form)
#
#     def get_success_url(self):
#         return reverse("completed")
#
#
# from django.views.generic import View
# from django.views.generic.edit import FormMixin
# class ContactFormView(View):
#     template_name = "contact.html"
#     form_class = ContactForm
#
#
#     def get_context_data(self, **kwargs):
#         context = super().get_context_data(**kwargs)
#         context['form'] = ContactForm()
#         return context
#
#     def post(self, request, *args, **kwargs):
#         if not request.user.is_authenticated:
#             return HttpResponseForbidden()
#         self.object = self.get_object()
#         form = self.get_form()
#         if form.is_valid():
#             return self.form_valid(form)
#         else:
#             return self.form_invalid(form)
#
#     def form_valid(self, form):
#         # Here, we would record the user's interest using the message
#         # passed in form.cleaned_data['message']
#         return super().form_valid(form)


class ContactFormView(ContactFormMixin, FormView):
    template_name = "contact.html"
    form_class = ContactForm

    def get_context_data(self, **kwargs):
        context = super(ContactFormView, self).get_context_data(**kwargs)
        context['url'] = 'contact'
        context['COMPANY_LAT'] = settings.COMPANY_INFOS['LAT']
        context['COMPANY_LNG'] = settings.COMPANY_INFOS['LNG']
        context['COMPANY_NAME'] = settings.COMPANY_INFOS['NAME']
        context['COMPANY_ADDRESS'] = settings.COMPANY_INFOS['ADDRESS']
        context['COMPANY_ZIP'] = settings.COMPANY_INFOS['ZIP']
        context['COMPANY_CITY'] = settings.COMPANY_INFOS['CITY']
        context['COMPANY_PHONE'] = settings.COMPANY_INFOS['PHONE']
        context['COMPANY_EMAIL'] = settings.COMPANY_INFOS['EMAIL']
        context['COMPANY_FACEBOOK'] = settings.COMPANY_INFOS['FACEBOOK']
        context['COMPANY_LINKEDIN'] = settings.COMPANY_INFOS['LINKEDIN']
        context['COMPANY_TWITTER'] = settings.COMPANY_INFOS['TWITTER']
        context['COMPANY_GOOGLEPLUS'] = settings.COMPANY_INFOS['GOOGLEPLUS']
        return context



from django.conf.urls import include, url
from django.contrib import admin
from example.views import IndexView

app_name = 'contact_form_bootstrap'

urlpatterns = [
    url(r'^$', IndexView.as_view(), name="homepage"),
    url(r'^admin/', admin.site.urls),
    url(r'^contact/', include(
        ("contact_form_bootstrap.urls", 'contact_form_bootstrap'),
        namespace="contact_form_bootstrap")
    ),
]



from django.urls import re_path

from contact_form_bootstrap.views import ContactFormView, CompletedPage


urlpatterns = [
    re_path(r'^$', ContactFormView.as_view(), name="contact"),
    re_path(r'^completed/$', CompletedPage.as_view(), name="completed"),
]



#!/usr/bin/python
# ex:set fileencoding=utf-8:

import os
import sys
import re

from setuptools import setup, find_packages
from setuptools.command.test import test as TestCommand

import contact_form_bootstrap

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()


install_requires = [
    'django-crispy-bootstrap==0.1.1.1',
    'django-crispy-forms>=1.11.2',
    'django-recaptcha==2.0.6',
    'requests==2.25.1',
]

prod_requires = [
]

dev_requires = [
#    'flake8>=1.6,<2.0',
    'django-extensions>=1.5.5',
    'django-debug-toolbar>=1.3.0',
]

tests_require = [
    'pytest',
    'pytest-cov==2.11.1',
    'pytest-django',
    'mock',
    'coverage==5.5',
]


class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        #import here, cause outside the eggs aren't loaded
        import pytest
        errno = pytest.main(self.test_args)
        sys.exit(errno)


# Thank django-rest-framework team for the idea
def get_version(package):
    """
    Return package version as listed in `VERSION` in `init.py`.
    """
    init_py = open(os.path.join(package, '__init__.py')).read()
    return re.search("VERSION = ['\"]([^'\"]+)['\"]", init_py).group(1)


version = get_version('contact_form_bootstrap')
if sys.argv[-1] == 'publish':
    if os.system("pip freeze | grep wheel"):
        print("wheel not installed.\nUse `pip install wheel`.\nExiting.")
        sys.exit()
    if os.system("pip freeze | grep twine"):
        print("twine not installed.\nUse `pip install twine`.\nExiting.")
        sys.exit()
    os.system("python setup.py sdist bdist_wheel")
    os.system("twine upload dist/*")
    print("You probably want to also tag the version now:")
    print("  git tag -a %s -m 'version %s'" % (version, version))
    print("  git push --tags")
    sys.exit()


setup(
    name='django_contactform_bootstrap',
    version=contact_form_bootstrap.VERSION,
    packages=find_packages('.'),
    include_package_data=True,
    license='BSD License',  # example.new license
    description='A Django Base contact form with bootstrap 3 and map.',
    long_description=README,
    url='http://www.github.com/alainivars/contact_form_bootstrap/',
    author='James Bennett, Alain Ivars',
    author_email='alainivars@highfeature.com',
    extras_require={
        'tests': tests_require,
        'dev': dev_requires,
        'prod': prod_requires,
    },
    install_requires=install_requires,
    tests_require=tests_require,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        # Replace these appropriately if you are stuck on Python 2.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    cmdclass={'test': PyTest},
)
